Crate kcr_ipam_metal3_io

Crate kcr_ipam_metal3_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the ipam.metal3.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

ipam.metal3.io/v1alpha1

  • IPAddress
  • IPClaim
  • IPPool

Modules

v1alpha1